# infer_subc/workflows

Code for classes which interface with the sibling napari plugin repo `organelle-segmenter-plugin` documented at [ndcn.github.io/organelle-segmenter-plugin](https://ndcn.github.io/organelle-segmenter-plugin/)


# infer_subc/workflow for napari plugin

The `workflow` sub-module is designed to interface with this repo (`infer_subc`) and the sibling [napari](https://napari.org/stable/) plugin repo [organelle-segmenter-plugin](https://github.com/ndcn/organelle-segmenter-plugin)

### workflow sub-modules

::: infer_subc.workflow.workflow

::: infer_subc.workflow.workflow_config

::: infer_subc.workflow.workflow_definition

::: infer_subc.workflow.workflow_engine

::: infer_subc.workflow.workflow_step
